@@ -6,7 +6,7 @@
 '''
 
 __author__ = 'Matt Joyce'
-__email__ = 'matt@nycresistor.com'
+__email__ = 'matt@joyce.nyc'
 __copyright__ = 'Copyright 2016, Symphony Communication Services LLC'
 
 import tempfile
