@@ -12,11 +12,11 @@ __copyright__ = 'Copyright 2016, Symphony Communication Services LLC'
 
 import symphony
 
-from users import Users
-from streams import Streams
-from groups import Groups
-from connections import Connections
-from base import Base
+from .users import Users
+from .streams import Streams
+from .groups import Groups
+from .connections import Connections
+from .base import Base
 
 
 class Pod(Base, Users, Streams, Groups, Connections):
